==> csircd-1.13.tar.gz: csircd-1.13/include/conf.h <==
#ifndef __MYCONF_H__
#define __MYCONF_H__

#include "setup.h"
#ifdef HAVE_TIME_H
#include <time.h>
#endif
#ifdef HAVE_SYS_TIME_H
#include <sys/time.h>
#endif
#include "access.h"
#include "fdlist.h"
#include "structs.h"
#include "log.h"


typedef struct _oline			OLINE;
typedef struct _ircdconf 		IRCDCONF;
typedef struct _servlink		SERVLINK;
typedef struct _class			CLASS;
typedef struct _stringdeny			STRINGDENY;
typedef struct _badircname		BADIRCNAME;
typedef struct _ircd_motd		IRCD_MOTD;

extern IRCDCONF		_ircd_conf;

struct _oline
{
	char		*hostname;
	char		*username;
	char		*ipstring;
	char		*passwd;
	char		*name;
	char		*classname;
#define OLINE_FLAGS_LOCAL			0x001
#define OLINE_FLAGS_CANKLINE		0x002
#define OLINE_FLAGS_CANGLINE		0x004
#define OLINE_FLAGS_CANLOCALROUTE	0x008
#define OLINE_FLAGS_CANGLOBALROUTE	0x010
#define OLINE_FLAGS_CANLOCALKILL	0x020
#define OLINE_FLAGS_CANGLOBALKILL	0x040
#define OLINE_FLAGS_CANFLOOD		0x080
#define OLINE_FLAGS_CANSET			0x100
#define OLINE_FLAGS_CANDIE			0x200
#define OLINE_FLAGS_CANUNKLINE		0x400
#define OLINE_FLAGS_CANREHASH		0x800
	int			flags;
	int			userflags;
	OLINE		*next;
};

struct _class
{
	int			size;
	int			num;
	IRCD_CLASSENTRY	**entries; /* array of pointers */
};

struct _stringdeny
{
	char			*name;
	char			*reason;
	int				expires;
	u_int			flags;

	STRINGDENY		*next;
	STRINGDENY		*prev;
};

struct _ircdconf
{
	char				*name;
	char				*info;

	struct sockaddr_in	*ns_list;
	int					ns_num;

	ACCESS			allow;
	ACCESS			deny;

	OLINE			*olines;

	CLASS			classes;
	SERVLINK		*servers;

	IRCD_LISTENER	*listeners;

	STRINGDENY		*nickname_denies;
	STRINGDENY		*ircname_denies;
	STRINGDENY		*channel_denies;

	char			**admin;

/* logs */
	aLog			*log_gline;
	aLog			*log_dline;
	aLog			*log_badoper;
	aLog			*log_goodoper;
	aLog			*log_clones;
	aLog			*log_users;

};

struct _servlink
{
	char			*servername;
	char			*username;
	char			*hostname;
	ircd_uint32_t	bindipaddr;
	struct in_addr	inaddr;
	ircd_uint16_t	port;

	int				res_starttime;

	IRCDRES_REQLIST	*res_req;

	char			*cpasswd;
	char			*npasswd;

	char			*classname;
	void			*classptr;
	int				hostmask;
#define SERVLINK_FLAGS_AUTOCONN		0x001
#define SERVLINK_FLAGS_DOINGDNS		0x002
#define SERVLINK_FLAGS_HIDEHOSTNAME	0x004
#define SERVLINK_FLAGS_DOINGCONNECT	0x008
	int				flags;

	int				tryconnecttime;
	int				lastconnect;

	IRCD_STRINGLIST	*hubs;
	IRCD_STRINGLIST	*leafs;

	SERVLINK		*next;
};

struct _ircd_motd
{
	struct tm	motd_time;
	char		**lines;
	int			size;
};

#define motd_time(_x)	((_x)->motd_time)
#define motd_lines(_x)	((_x)->lines)

int ircdconf_prepare_rehash(IRCDCONF *ircdconf);
int ircdconf_rehash(void);
int ircdconf_init(IRCDCONF *ircdconf);
int ircdconf_read(char *filename, IRCDCONF *ircdconf);

int listener_clear(IRCD_LISTENER **lptr);
int listener_add(IRCD_LISTENER **lptr, int port, ircd_uint32_t ipaddr, int flags, int aflags);
int servlink_clear(SERVLINK **slptr);
int servlink_add(SERVLINK **slptr, char *server, char *hostname, char *username, char *cpasswd, char *npasswd, int hostmask, int port, int flags, int aflags, IRCD_STRINGLIST *hubs, IRCD_STRINGLIST *leafs, char *class, ircd_uint32_t bindipaddr);
SERVLINK *servlink_find(char *servername, IRCD_CLIENT *pptr);
int class_del(CLASS *cptr, IRCD_CLASSENTRY *ceptr);
int class_clear(CLASS *cptr);
int class_add(CLASS *cptr, IRCD_CLASSENTRY *ceptr);
int oline_clear(OLINE **coptr);
int oline_add(OLINE **coptr, char *hostname, char *username, char *name, char *passwd, int flags, int aflags, char *class, int userflags);
int oline_find(OLINE **coptr, char *name, char *username, char *hostname, ircd_uint32_t ipaddr, OLINE **corptr);
int class_find(CLASS *cptr, char *class, IRCD_CLASSENTRY **classptr);
int ircd_checkallow(IRCD_CLIENT *pptr, int *err);
int motd_unload(IRCD_MOTD **motd);
int motd_load(char *filename, IRCD_MOTD **motd_ptr);
char *conf_myname_for_link(char *name, int hostmask, char *buf);
void logs_init(void);
void stringdeny_add(STRINGDENY **stlist, char *name, char *reason, int expires, u_int flags);
void stringdeny_del(STRINGDENY **stlist, STRINGDENY *sptr);
STRINGDENY *stringdeny_find(STRINGDENY **stlist, char *name, int expires);
STRINGDENY *stringdeny_match(STRINGDENY **stlist, char *name, int expires);
void stringdeny_free(STRINGDENY **stlist);

#endif

==> csircd-1.14.tar.gz: csircd-1.14/include/conf.h <==
#ifndef __MYCONF_H__
#define __MYCONF_H__

#include "setup.h"
#ifdef HAVE_TIME_H
#include <time.h>
#endif
#ifdef HAVE_SYS_TIME_H
#include <sys/time.h>
#endif
#include "access.h"
#include "fdlist.h"
#include "structs.h"
#include "log.h"


typedef struct _oline			OLINE;
typedef struct _ircd_deny_acl	IRCD_DENY_ACL;
typedef struct _ircdconf 		IRCDCONF;
typedef struct _servlink		SERVLINK;
typedef struct _class			CLASS;
typedef struct _stringdeny			STRINGDENY;
typedef struct _badircname		BADIRCNAME;
typedef struct _ircd_motd		IRCD_MOTD;

extern IRCDCONF		_ircd_conf;


struct _oline
{
	char		*hostname;
	char		*username;
	char		*ipstring;
	char		*passwd;
	char		*name;
	char		*classname;
#define OLINE_FLAGS_LOCAL				0x00000001
#define OLINE_FLAGS_CANKLINE			0x00000002
#define OLINE_FLAGS_CANGLINE			0x00000004
#define OLINE_FLAGS_CANLOCALROUTE		0x00000008
#define OLINE_FLAGS_CANGLOBALROUTE		0x00000010
#define OLINE_FLAGS_CANLOCALKILL		0x00000020
#define OLINE_FLAGS_CANGLOBALKILL		0x00000040
#define OLINE_FLAGS_CANFLOOD			0x00000080
#define OLINE_FLAGS_CANSET				0x00000100
#define OLINE_FLAGS_CANDIE				0x00000200
#define OLINE_FLAGS_CANUNKLINE			0x00000400
#define OLINE_FLAGS_CANREHASH			0x00000800
#define OLINE_FLAGS_CANREMOTEKLINE		0x00001000
#define OLINE_FLAGS_CANREMOTEUNKLINE	0x00002000
#define OLINE_FLAGS_CANRESTART			0x00004000
	int			flags;
	int			userflags;
	OLINE		*next;
};

struct _class
{
	int					size;
	int					num;
	IRCD_CLASSENTRY		**entries; /* array of pointers */
};

struct _stringdeny
{
	char				*name;
	char				*reason;
	int					expires;
	u_int				flags;

	STRINGDENY			*next;
	STRINGDENY			*prev;
};

struct _ircd_deny_acl
{
	char				*src_oper_username;
	char				*src_oper_hostname;
	char				*src_server;
	char				*dest_mask_username;
	char				*dest_mask_hostname;

#define IRCD_DENY_ACL_FLAGS_ALLOW	0x001
	u_int				flags;

	IRCD_DENY_ACL		*next;
};

struct _ircdconf
{
	char				*name;
	char				*info;

	struct sockaddr_in	*ns_list;
	int					ns_num;

	ACCESS				allow;
	ACCESS				deny;

	OLINE				*olines;

	CLASS				classes;
	SERVLINK			*servers;

	IRCD_LISTENER		*listeners;

	STRINGDENY			*nickname_denies;
	STRINGDENY			*ircname_denies;
	STRINGDENY			*channel_denies;

	IRCD_DENY_ACL		*gline_acls;
	IRCD_DENY_ACL		*gline_acls_last;
	IRCD_DENY_ACL		*kline_acls;
	IRCD_DENY_ACL		*kline_acls_last;
	IRCD_DENY_ACL		*unkline_acls;
	IRCD_DENY_ACL		*unkline_acls_last;

	char				**admin;

/* logs */
	aLog				*log_gline;
	aLog				*log_dline;
	aLog				*log_badoper;
	aLog				*log_goodoper;
	aLog				*log_clones;
	aLog				*log_users;

};

struct _servlink
{
	char			*servername;
	char			*username;
	char			*hostname;
	ircd_uint32_t	bindipaddr;
	struct in_addr	inaddr;
	ircd_uint16_t	port;

	int				recv_buffer_size;
	int				send_buffer_size;

	int				res_starttime;

	IRCDRES_REQLIST	*res_req;

	char			*cpasswd;
	char			*npasswd;

	char			*classname;
	void			*classptr;
	int				hostmask;
#define SERVLINK_FLAGS_AUTOCONN		0x001
#define SERVLINK_FLAGS_DOINGDNS		0x002
#define SERVLINK_FLAGS_HIDEHOSTNAME	0x004
#define SERVLINK_FLAGS_DOINGCONNECT	0x008
	int				flags;

	int				tryconnecttime;
	int				lastconnect;

	IRCD_STRINGLIST	*hubs;
	IRCD_STRINGLIST	*leafs;

	SERVLINK		*next;
};

struct _ircd_motd
{
	struct tm	motd_time;
	char		**lines;
	int			size;
};

#define motd_time(_x)	((_x)->motd_time)
#define motd_lines(_x)	((_x)->lines)

int ircdconf_prepare_rehash(IRCDCONF *ircdconf);
int ircdconf_rehash(void);
int ircdconf_init(IRCDCONF *ircdconf);
int ircdconf_read(char *filename, IRCDCONF *ircdconf);

int listener_clear(IRCD_LISTENER **lptr);
int listener_add(IRCD_LISTENER **lptr, int port, ircd_uint32_t ipaddr, int flags, int aflags);
int servlink_clear(SERVLINK **slptr);
int servlink_add(SERVLINK **slptr, char *server, char *hostname, char *username, char *cpasswd, char *npasswd, int hostmask, int port, int flags, int aflags, IRCD_STRINGLIST *hubs, IRCD_STRINGLIST *leafs, char *class, ircd_uint32_t bindipaddr);
SERVLINK *servlink_find(char *servername, IRCD_CLIENT *pptr);
int class_del(CLASS *cptr, IRCD_CLASSENTRY *ceptr);
int class_clear(CLASS *cptr);
int class_add(CLASS *cptr, IRCD_CLASSENTRY *ceptr);
int oline_clear(OLINE **coptr);
int oline_add(OLINE **coptr, char *hostname, char *username, char *name, char *passwd, int flags, int aflags, char *class, int userflags);
int oline_find(OLINE **coptr, char *name, char *username, char *hostname, ircd_uint32_t ipaddr, OLINE **corptr);
int class_find(CLASS *cptr, char *class, IRCD_CLASSENTRY **classptr);
int ircd_checkallow(IRCD_CLIENT *pptr, int *err);
int motd_unload(IRCD_MOTD **motd);
int motd_load(char *filename, IRCD_MOTD **motd_ptr);
char *conf_myname_for_link(char *name, int hostmask, char *buf);
void logs_init(void);
void stringdeny_add(STRINGDENY **stlist, char *name, char *reason, int expires, u_int flags);
void stringdeny_del(STRINGDENY **stlist, STRINGDENY *sptr);
STRINGDENY *stringdeny_find(STRINGDENY **stlist, char *name, int expires);
STRINGDENY *stringdeny_match(STRINGDENY **stlist, char *name, int expires);
void stringdeny_free(STRINGDENY **stlist);
void build_isupport(void);
void send_isupport_to_one(IRCD_CLIENT *one);
IRCD_DENY_ACL *deny_acl_find(IRCD_DENY_ACL *acl, char *oper_username, char *oper_hostname, char *server, char *mask_username, char *mask_hostname);

#endif
